@@ -2,7 +2,7 @@
 """
 @Author: HuangJianYi
 @Date: 2021-07-26 18:31:06
-@LastEditTime: 2022-09-02 11:19:15
+@LastEditTime: 2022-11-14 15:08:20
 @LastEditors: HuangJianYi
 @Description: 
 """
@@ -43,7 +43,9 @@ class LoginHandler(ClientBaseHandler):
         invoke_result_data = self.business_process_executing()
         if invoke_result_data.success == False:
             return self.response_json_error(invoke_result_data.error_code, invoke_result_data.error_message)
-
+        if not invoke_result_data.data:
+            invoke_result_data.data = {}
+        is_update_user_nick = invoke_result_data.data["is_update_user_nick"] if invoke_result_data.data.__contains__("is_update_user_nick") else True
         login_ip = self.get_remote_ip()
         union_id = ""
         if pt == "wx" and code:
@@ -61,7 +63,7 @@ class LoginHandler(ClientBaseHandler):
             login_ip = self.get_param("source_ip")
 
         user_base_model = UserBaseModel(context=self)
-        invoke_result_data = user_base_model.save_user_by_openid(app_id, act_id, open_id, user_nick, avatar, union_id, login_ip)
+        invoke_result_data = user_base_model.save_user_by_openid(app_id, act_id, open_id, user_nick, avatar, union_id, login_ip, is_update_user_nick)
         if invoke_result_data.success == False:
             return self.response_json_error(invoke_result_data.error_code, invoke_result_data.error_message)
         invoke_result_data.data["user_nick"] = CryptographyHelper.emoji_base64_to_emoji(invoke_result_data.data["user_nick"])
