@@ -544,7 +544,7 @@ class FrameBaseHandler(BaseApiHandler):
         if not handler_name:
             handler_name = self.__class__.__name__
         operate_base_model = OperateBaseModel(context=self)
-        operate_base_model.add_operation_log(operation_type, title, operation_desc, model_name, handler_name, old_detail, update_detail, self.get_app_id(), self.get_act_id(), operate_user_id, operate_user_name, operate_role_id, {"request_params": self.request_params, "request": self.request}, self.get_remote_ip())
+        operate_base_model.add_operation_log(operation_type, title, operation_desc, model_name, handler_name, old_detail, update_detail, self.get_app_id(), self.get_act_id(), operate_user_id, operate_user_name, operate_role_id, {"request_params": self.request_params, "request": self.request}, self.get_remote_ip(), self.request_code)
 
     def check_continue_request(self, handler_name, app_id, object_id, expire=100):
         """
@@ -656,7 +656,7 @@ class ClientBaseHandler(FrameBaseHandler):
         clientheaderinfo_string = self.request.headers._dict.get("Clientheaderinfo")
         if clientheaderinfo_string:
             info_model = parse_qs(clientheaderinfo_string)
-            device_info_dict["pid"] = int(info_model["pid"][0])  # 产品标识
+            device_info_dict["pid"] = (info_model["pid"][0])  # 产品标识
             device_info_dict["chid"] = 0 if "chid" not in info_model.keys() else int(info_model["chid"][0])  # 渠道标识
             device_info_dict["height"] = 0 if "height" not in info_model.keys() else int(float(info_model["height"][0]))  # 高度
             device_info_dict["width"] = 0 if "width" not in info_model.keys() else int(float(info_model["width"][0]))  # 宽度
