@@ -2,7 +2,7 @@
 """
 :Author: HuangJianYi
 :Date: 2021-08-03 10:11:39
-@LastEditTime: 2022-06-09 14:46:01
+@LastEditTime: 2022-10-17 17:40:25
 @LastEditors: HuangJianYi
 :description: 商品模块
 """
@@ -199,7 +199,7 @@ class BindSpecialGoodsHandler(ClientBaseHandler):
 
         goods_base_model = GoodsBaseModel(context=self)
         app_key, app_secret = self.get_app_key_secret()
-        invoke_result_data = goods_base_model.bind_special_goods(app_id, goods_id, goods_name, access_token, app_key, access_token, is_log)
+        invoke_result_data = goods_base_model.bind_special_goods(app_id, goods_id, goods_name, access_token, app_key, app_secret, is_log)
         if invoke_result_data.success == False:
             return self.response_json_error(invoke_result_data.error_code, invoke_result_data.error_message)
         return self.response_json_success()
\ No newline at end of file
