@@ -2,7 +2,7 @@
 """
 @Author: HuangJianYi
 @Date: 2021-08-19 09:23:14
-@LastEditTime: 2022-10-18 16:59:46
+@LastEditTime: 2022-11-15 09:44:54
 @LastEditors: HuangJianYi
 @Description: 
 """
@@ -30,18 +30,19 @@ class WeChatHelper:
     :description: 微信帮助类 1.临时登录凭证校验获取open_id、session_key  2.解析加密数据
     """
     logger_error = Logger.get_logger_by_name("log_error")
-    
+
     @classmethod
-    def get_web_authorize_url(self, app_id, redirect_uri, scope="snsapi_userinfo", state="1"):
+    def get_web_authorize_url(self, redirect_uri, scope="snsapi_userinfo", app_id="", state="1"):
         """
         :description:获取网页授权链接
-        :param app_id：公众号的唯一标识
         :param redirect_uri：授权后重定向的回调地址，请使用urlencode对链接进行处理
         :param scope：应用授权作用域，snsapi_base （不弹出授权页面，直接跳转，只能获取用户openid），snsapi_userinfo （弹出授权页面，可通过openid拿到昵称、性别、所在地。并且，即使在未关注的情况下，只要用户授权，也能获取其信息）
+        :param app_id：公众号的唯一标识
         :param state：重定向后会带上state参数，开发者可以填写a-zA-Z0-9的参数值，最多128字节
         :return: 返回网页授权链接
         :last_editors: HuangJianYi
         """
+        app_id = app_id if app_id else config.get_value("app_id")
         authorize_url = "https://open.weixin.qq.com/connect/oauth2/authorize?appid={0}&redirect_uri={1}&response_type=code&scope={2}&state={3}&connect_redirect=1#wechat_redirect".format(app_id,CodingHelper.url_encode(redirect_uri),scope,CodingHelper.url_encode(state))
         return authorize_url
 
@@ -96,10 +97,82 @@ class WeChatHelper:
             invoke_result_data.error_message = traceback.format_exc()
             return invoke_result_data
 
+    @classmethod
+    def get_jsapi_ticket(self, app_id="", app_secret="", is_del=False):
+        """
+        :description:获取jsapi_ticket
+        :param app_id:app_id
+        :param app_secret:app_secret
+        :param is_del:是否删除redis里的ticket
+        :return: 返回ticket
+        :last_editors: HuangJianYi
+        """
+        app_id = app_id if app_id else config.get_value("app_id")
+        app_secret = app_secret if app_secret else config.get_value("app_secret")
+        invoke_result_data = InvokeResultData()
+        for i in range(2):
+            if i == 0:
+                invoke_result_data = self.get_access_token(app_id, app_secret)
+            else:
+                invoke_result_data = self.get_access_token(app_id, app_secret, True)
+
+            if invoke_result_data.success == True:
+                break
+        if invoke_result_data.success == False:
+            return invoke_result_data
+        access_token = invoke_result_data.data
+        response = None
+        redis_init = SevenHelper.redis_init(config_dict=config.get_value("platform_redis"))
+        redis_key = f"wechat_jsapi_ticket:{str(app_id)}"
+        if is_del == True:
+            redis_init.delete(redis_key)
+        try:
+            jsapi_ticket = redis_init.get(redis_key)
+            if jsapi_ticket:
+                invoke_result_data.data = jsapi_ticket
+                return invoke_result_data
+            requset_url = f"https://api.weixin.qq.com/cgi-bin/ticket/getticket?access_token={access_token}&type=jsapi"
+            response = requests.get(requset_url)
+            response_data = SevenHelper.json_loads(response.text)
+            if response_data.__contains__("errcode") and response_data["errcode"] != 0:
+                invoke_result_data.success = False
+                invoke_result_data.error_code = response_data["errcode"]
+                invoke_result_data.error_message = response_data["errmsg"]
+                return invoke_result_data
+            invoke_result_data.data = str(response_data["ticket"])
+            redis_init.set(redis_key, invoke_result_data.data, ex=3600)
+            return invoke_result_data
+        except Exception as ex:
+            self.logger_error.error("【get_jsapi_ticket】" + traceback.format_exc())
+            invoke_result_data.success = False
+            invoke_result_data.error_code = "exception"
+            invoke_result_data.error_message = traceback.format_exc()
+            return invoke_result_data
+
+    @classmethod
+    def get_share_sign_package(self, request_url, app_id="", app_secret=""):
+        """
+        :description:获取分享请求参数
+        :param request_url:请求地址
+        :param app_id:app_id
+        :param app_secret:app_secret
+        :return: 返回分享请求参数
+        :last_editors: HuangJianYi
+        """
+        request_url = request_url.split('#')[0]
+        timestamp = int(time.time())
+        js_ticket = self.get_jsapi_ticket(app_id, app_secret,True)
+        noncestr = self.get_nonce_str()
+        param = {'noncestr': noncestr, 'jsapi_ticket': js_ticket, 'timestamp': timestamp, 'url': request_url}
+        string_sign_temp = self.key_value_url(param)
+        sign = hashlib.sha1(string_sign_temp.encode("utf8")).hexdigest()
+        sign_package = {'appid': app_id, 'noncestr': noncestr, 'timestamp': timestamp, 'url': request_url, 'signature': sign}
+        return sign_package
+
     @classmethod
     def code2_session(self, code, grant_type="authorization_code", app_id="", app_secret=""):
         """
-        :description:临时登录凭证校验
+        :description:小程序临时登录凭证校验
         :param code：登录票据
         :param grant_type：授权方式
         :param app_id：app_id
@@ -151,7 +224,7 @@ class WeChatHelper:
     @classmethod
     def get_access_token(self, app_id="", app_secret="", is_del=False, grant_type="client_credential"):
         """
-        :description:access_token 是小程序的全局唯一调用凭据，开发者调用小程序支付时需要使用 access_token。access_token 的有效期为 2 个小时，需要定时刷新 access_token，重复获取会导致之前一次获取的 access_token 的有效期缩短为 5 分钟。建议开发者使用中控服务器统一获取和刷新 access_token，其他业务逻辑服务器所使用的 access_token 均来自于该中控服务器，不应该各自去刷新，否则容易造成冲突，导致 access_token 覆盖而影响业务；
+        :description:access_token 是微信的全局唯一调用凭据，开发者调用小程序支付时需要使用 access_token。access_token 的有效期为 2 个小时，需要定时刷新 access_token，重复获取会导致之前一次获取的 access_token 的有效期缩短为 5 分钟。建议开发者使用中控服务器统一获取和刷新 access_token，其他业务逻辑服务器所使用的 access_token 均来自于该中控服务器，不应该各自去刷新，否则容易造成冲突，导致 access_token 覆盖而影响业务；
         :param app_id:app_id
         :param app_secret:app_secret
         :param is_del:是否删除redis里的access_token
