@@ -40,20 +40,21 @@ class AppBaseModel():
             app_id = app_info_dict["app_id"]
         return app_id
 
-    def get_app_info_dict(self,app_id,is_cache=True):
+    def get_app_info_dict(self, app_id, is_cache=True, field="*"):
         """
         :description: 获取应用信息
         :param app_id: 应用标识
         :param is_cache: 是否缓存
+        :param field: 查询字段
         :return: 返回应用信息
         :last_editors: HuangJianYi
         """
         app_info_model = AppInfoModel(context=self.context)
         if is_cache:
             dependency_key = DependencyKey.app_info(app_id)
-            return app_info_model.get_cache_dict(dependency_key=dependency_key, limit="1", where="app_id=%s", params=[app_id])
+            return app_info_model.get_cache_dict(where="app_id=%s",limit="1", field=field, params=[app_id],dependency_key=dependency_key)
         else:
-            return app_info_model.get_dict(where="app_id=%s", limit="1", params=[app_id])
+            return app_info_model.get_dict(where="app_id=%s", limit="1",field=field, params=[app_id])
 
     def get_app_expire(self,app_id):
         """
