@@ -151,6 +151,7 @@ class AssetBaseModel():
             return invoke_result_data
         #如果only_id已经存在，直接在redis进行拦截,减少数据库的请求，时限1天
         redis_init = SevenHelper.redis_init()
+        is_asset_warn = config.get_value("is_asset_warn",False) #是否开启资产预警，跟控制台配套使用
         only_cache_key = ""
         if only_id:
             only_cache_key = f"asset_only_list:{act_id}_{SevenHelper.get_now_day_int()}"
@@ -159,29 +160,31 @@ class AssetBaseModel():
                 invoke_result_data.error_code = "error"
                 invoke_result_data.error_message = "only_id已经存在"
                 
-                asset_warn_notice = AssetWarnNotice()
-                asset_warn_notice.app_id = app_id
-                asset_warn_notice.act_id = act_id
-                asset_warn_notice.ascription_type = 2
-                asset_warn_notice.handler_name = handler_name
-                asset_warn_notice.request_code = request_code
-                asset_warn_notice.user_id = user_id
-                asset_warn_notice.open_id = open_id
-                asset_warn_notice.user_nick = user_nick
-                asset_warn_notice.asset_type =asset_type
-                asset_warn_notice.asset_object_id = asset_object_id
-                asset_warn_notice.log_title = source_object_name if source_object_name else log_title
-                if source_type == 1:
-                    asset_warn_notice.info_desc = f"重复请求{asset_warn_notice.log_title}【订单号：{only_id}】"
-                else:
-                    asset_warn_notice.info_desc = f"重复请求{asset_warn_notice.log_title}"
-                asset_warn_notice.info_json = {"asset_value":asset_value}
-                asset_warn_notice.create_date = SevenHelper.get_now_datetime()
-                asset_warn_notice.create_day = SevenHelper.get_now_day_int()
-                redis_init.rpush("asset_intercept_queue_list",SevenHelper.json_dumps(asset_warn_notice))
-                redis_init.expire("asset_intercept_queue_list", 7 * 24 * 3600)
-                #添加唯一标识预警拦截计数,用于控制台跑数据进行并发预警
-                self._add_onlyid_warn_stat(handler_name)
+                if is_asset_warn == True:
+                    asset_warn_notice = AssetWarnNotice()
+                    asset_warn_notice.app_id = app_id
+                    asset_warn_notice.act_id = act_id
+                    asset_warn_notice.ascription_type = 2
+                    asset_warn_notice.handler_name = handler_name
+                    asset_warn_notice.request_code = request_code
+                    asset_warn_notice.user_id = user_id
+                    asset_warn_notice.open_id = open_id
+                    asset_warn_notice.user_nick = user_nick
+                    asset_warn_notice.asset_type =asset_type
+                    asset_warn_notice.asset_object_id = asset_object_id
+                    asset_warn_notice.log_title = source_object_name if source_object_name else log_title
+                    if source_type == 1:
+                        asset_warn_notice.info_desc = f"重复请求{asset_warn_notice.log_title}【订单号：{only_id}】"
+                    else:
+                        asset_warn_notice.info_desc = f"重复请求{asset_warn_notice.log_title}"
+                    asset_warn_notice.info_json = {"asset_value":asset_value}
+                    asset_warn_notice.create_date = SevenHelper.get_now_datetime()
+                    asset_warn_notice.create_day = SevenHelper.get_now_day_int()
+                    redis_init.rpush("asset_intercept_queue_list",SevenHelper.json_dumps(asset_warn_notice))
+                    redis_init.expire("asset_intercept_queue_list", 7 * 24 * 3600)
+                    #添加唯一标识预警拦截计数,用于控制台跑数据进行并发预警
+                    self._add_onlyid_warn_stat(handler_name)
+                
                 return invoke_result_data
         db_transaction = DbTransaction(db_config_dict=config.get_value("db_cloudapp"),context=self.context)
         user_asset_model = UserAssetModel(db_transaction=db_transaction, context=self.context)
@@ -287,7 +290,7 @@ class AssetBaseModel():
 
             result,message = db_transaction.commit_transaction(return_detail_tuple=True)
             if result == False:
-                if only_id:
+                if only_id and is_asset_warn == True:
                     #添加唯一标识预警拦截计数,用于控制台跑数据进行并发预警
                     self._add_onlyid_warn_stat(handler_name)
                 if self.context:
@@ -304,22 +307,23 @@ class AssetBaseModel():
                     redis_init.hset(only_cache_key, only_id, 1)
                     redis_init.expire(only_cache_key, 24 * 3600)
                 self._delete_asset_dependency_key(act_id,user_id)
-
-                asset_queue = {}
-                asset_queue["app_id"] = app_id
-                asset_queue["act_id"] = act_id
-                asset_queue["open_id"] = open_id
-                asset_queue["user_nick"] = user_nick
-                asset_queue["user_id"] = user_id
-                asset_queue["asset_type"] = asset_type
-                asset_queue["asset_object_id"] = asset_object_id
-                asset_queue["now_value"] = user_asset.asset_value
-                asset_queue["operate_value"] = asset_value
-                asset_queue["history_asset_value"] = history_asset_value
-                asset_queue["now_day_int"] = now_day_int
-                asset_queue["create_date"] = now_datetime
-                redis_init.rpush(f"asset_queue_list",SevenHelper.json_dumps(asset_queue))
-                redis_init.expire(f"asset_queue_list", 7 * 24 * 3600)
+                
+                if is_asset_warn == True:
+                    asset_queue = {}
+                    asset_queue["app_id"] = app_id
+                    asset_queue["act_id"] = act_id
+                    asset_queue["open_id"] = open_id
+                    asset_queue["user_nick"] = user_nick
+                    asset_queue["user_id"] = user_id
+                    asset_queue["asset_type"] = asset_type
+                    asset_queue["asset_object_id"] = asset_object_id
+                    asset_queue["now_value"] = user_asset.asset_value
+                    asset_queue["operate_value"] = asset_value
+                    asset_queue["history_asset_value"] = history_asset_value
+                    asset_queue["now_day_int"] = now_day_int
+                    asset_queue["create_date"] = now_datetime
+                    redis_init.rpush(f"asset_queue_list",SevenHelper.json_dumps(asset_queue))
+                    redis_init.expire(f"asset_queue_list", 7 * 24 * 3600)
             except Exception as ex:
                 if self.context:
                     self.context.logging_link_error("【资产队列】" + traceback.format_exc())
