@@ -2,7 +2,7 @@
 """
 @Author: HuangJianYi
 @Date: 2021-11-24 09:36:39
-@LastEditTime: 2022-05-20 09:05:10
+@LastEditTime: 2022-10-25 17:49:37
 @LastEditors: HuangJianYi
 @Description: ERP控制台业务模型(用于跟遁甲系统对接，推送订单和回写物流) 需在配置文件加 armor_url 和 armor_sign_key对应的值
 """
@@ -47,7 +47,7 @@ class ErpConsoleModel():
         :last_editors: HuangJianYi
         """
         page_size = 100
-        push_url = config.get_value("armor_url") + "/api/new_order"
+        push_url = config.get_value("armor_url","") + "/api/new_order"
         sign_key = config.get_value("armor_sign_key", "")
 
         print(f"{TimeHelper.get_now_format_time()} 推送订单队列{mod_value}启动")
@@ -116,6 +116,8 @@ class ErpConsoleModel():
         data["app_id"] = erp_relation_dict["app_id"]
         data["app_key"] = erp_relation_dict["app_key"]
         data["mini_order"] = prize_order_dict["order_no"]
+        data["user_id"] = prize_order_dict["user_id"]
+        data["open_id"] = prize_order_dict["open_id"]
         data["user_account"] = prize_order_dict["user_nick"]
         data["order_time"] = TimeHelper.datetime_to_timestamp(prize_order_dict["create_date"]) * 1000 if str(prize_order_dict["create_date"]) != "1900-01-01 00:00:00" else 0
         data["activity_id"] = prize_order_dict["act_id"]
@@ -130,6 +132,7 @@ class ErpConsoleModel():
         data["address"] = prize_order_dict["address"]
         data["remark"] = prize_order_dict["seller_remark"]
         data["buyer_remark"] = prize_order_dict["buyer_remark"]
+        data["freight_price"] = str(prize_order_dict["freight_price"])
         data["timestamp"] = TimeHelper.get_now_timestamp(True)
         data["order_status"] = prize_order_dict["order_status"]
         if data["order_status"] == 2:
@@ -230,7 +233,7 @@ class ErpConsoleModel():
                                     erp_redis_init.lpop(key)
                             else:
                                 page_size = 100
-                                pull_url = config.get_value("armor_url") + "/api/new_get_order"
+                                pull_url = config.get_value("armor_url","") + "/api/new_get_order"
                                 sign_key = config.get_value("armor_sign_key", "")
                                 condition = "app_id=%s and order_status=0 and sync_status=1"
                                 params = [erp_relation_dict["app_id"]]
