@@ -2,7 +2,7 @@
 """
 :Author: HuangJianYi
 :Date: 2020-05-02 15:17:41
-@LastEditTime: 2022-09-26 16:01:21
+@LastEditTime: 2022-09-28 11:56:59
 @LastEditors: HuangJianYi
 :description: 自定义实体模型
 """
@@ -228,14 +228,20 @@ class DependencyKey():
         return f"cms_info_list:placeid_{place_id}"
 
     @classmethod
-    def dict_info_list(self, parent_id):
+    def dict_info_list(self, parent_id, dict_type):
         """
         :description: 字典信息列表
         :param parent_id: 父节点标识
+        :param dict_type: 字典类型
         :return str
         :last_editors: HuangJianYi
         """
-        return f"dict_info_list:parentid_{parent_id}"
+        if parent_id and dict_type:
+            return f"dict_info_list:parentid_{parent_id}_dicttype_{dict_type}"
+        if parent_id:
+            return f"dict_info_list:parentid_{parent_id}"
+        if dict_type:
+            return f"dict_info_list:dicttype_{dict_type}"
 
     @classmethod
     def ip_info(self, ip_id):
