@@ -2,7 +2,7 @@
 """
 @Author: HuangJianYi
 @Date: 2021-07-26 09:39:08
-@LastEditTime: 2022-07-08 11:50:25
+@LastEditTime: 2022-08-24 16:21:23
 @LastEditors: HuangJianYi
 @Description: 
 """
@@ -25,7 +25,7 @@ class StatBaseModel(FrameBaseModel):
 
     def add_stat(self, app_id, act_id, module_id, user_id, open_id, key_name, key_value):
         """
-        :description: 添加上报
+        :description: 添加活动（模块）上报
         :param app_id：应用标识
         :param act_id：活动标识
         :param module_id：活动模块标识
@@ -61,7 +61,7 @@ class StatBaseModel(FrameBaseModel):
 
     def add_stat_list(self, app_id, act_id, module_id, user_id, open_id, stat_data):
         """
-        :description: 添加上报
+        :description: 添加活动（模块）上报
         :param app_id：应用标识
         :param act_id：活动标识
         :param module_id：活动模块标识
@@ -405,3 +405,48 @@ class StatBaseModel(FrameBaseModel):
         self.business_process_executed(act_id,module_id,user_id,handler_name,acquire_lock_name,identifier)
 
         return invoke_result_data
+
+
+    def add_stat_user_list(self, app_id, act_id, module_id, user_id, open_id, stat_data):
+        """
+        :description: 添加用户行为上报
+        :param app_id：应用标识
+        :param act_id：活动标识
+        :param module_id：活动模块标识
+        :param user_id：用户标识
+        :param open_id：open_id
+        :param stat_data:统计数据
+        :return:
+        :last_editors: HuangJianYi
+        """
+        stat_queue_list = []
+        if isinstance(stat_data,list):
+            for item in stat_data:
+                stat_queue = StatQueue()
+                stat_queue.app_id = app_id
+                stat_queue.act_id = act_id
+                stat_queue.module_id = module_id
+                stat_queue.user_id = user_id
+                stat_queue.open_id = open_id
+                stat_queue.key_name = item["key"]
+                stat_queue.key_value = item["value"]
+                stat_queue.create_date = SevenHelper.get_now_datetime()
+                stat_queue.process_date = SevenHelper.get_now_datetime()
+                stat_queue_list.append(stat_queue)
+        else:
+            for key,value in stat_data.items():
+                stat_queue = StatQueue()
+                stat_queue.app_id = app_id
+                stat_queue.act_id = act_id
+                stat_queue.module_id = module_id
+                stat_queue.user_id = user_id
+                stat_queue.open_id = open_id
+                stat_queue.key_name = key
+                stat_queue.key_value = value
+                stat_queue.create_date = SevenHelper.get_now_datetime()
+                stat_queue.process_date = SevenHelper.get_now_datetime()
+                stat_queue_list.append(stat_queue)
+
+        redis_init = SevenHelper.redis_init()
+        for stat_queue in stat_queue_list:
+            redis_init.rpush(f"stat_user_queue_list:{str(user_id % 10)}", SevenHelper.json_dumps(stat_queue))
\ No newline at end of file
