@@ -2,7 +2,7 @@
 """
 @Author: HuangJianYi
 @Date: 2021-07-22 11:10:20
-@LastEditTime: 2022-11-14 14:56:08
+@LastEditTime: 2022-11-15 11:12:09
 @LastEditors: HuangJianYi
 @Description: 
 """
@@ -783,7 +783,7 @@ class UserBaseModel(FrameBaseModel):
         :param act_id：活动标识
         :param user_id：用户标识
         :param open_id：open_id
-        :param user_address_id:用户地址标识
+        :param user_address_id:用户地址标识,如果传-1则优先获取最新一条并更新，适用于不需要获取地址列表的场景
         :param real_name：真实姓名
         :param telephone：手机号码
         :param province：省
@@ -826,9 +826,14 @@ class UserBaseModel(FrameBaseModel):
         user_address_model = UserAddressModel()
         if is_default == 1:
             user_address_model.update_table("is_default=0", "act_id=%s and user_id=%s", params=[act_id, user_id])
+        user_address = None
+        if user_address_id == -1:
+            user_address = user_address_model.get_entity("act_id=%s and user_id=%s", params=[act_id, user_id])
+            user_address_id = user_address.id if user_address else 0
 
         if user_address_id > 0:
-            user_address = user_address_model.get_entity("id=%s", params=[user_address_id])
+            if not user_address:
+                user_address = user_address_model.get_entity("id=%s", params=[user_address_id])
             if not user_address:
                 invoke_result_data.success = False
                 invoke_result_data.error_code = "error"
